@@ -219,6 +219,10 @@ sub register {
   my $r = $config->{route} || $app->routes->any('/');
   my ($base_path, $paths, $swagger);
 
+  if ($config->{controller}) {
+    warn "Default 'controller' in Swagger2 plugin config is deprecated!";
+  }
+
   $self->url($config->{url} || die "'url' is required config parameter");
   $self->{controller} = $config->{controller};    # back compat
   $app->helper(render_swagger => \&render_swagger);
@@ -250,8 +254,10 @@ sub register {
 sub _generate_request_handler {
   my ($self, $method, $config) = @_;
   my $controller = $config->{'x-mojo-controller'} || $self->{controller};    # back compat
+  my $defaults = {};
+  my $handler;
 
-  return sub {
+  $handler = sub {
     my $c = shift;
     my $method_ref;
 
@@ -291,6 +297,12 @@ sub _generate_request_handler {
       },
     );
   };
+
+  for my $p (@{$config->{parameters} || []}) {
+    $defaults->{$p->{name}} = $p->{default} if $p->{in} eq 'path' and defined $p->{default};
+  }
+
+  return $defaults, $handler;
 }
 
 sub _not_implemented {
@@ -316,6 +328,8 @@ sub _validate_input {
       : $in eq 'formData' ? $c->req->body_params->to_hash
       :                     "Invalid 'in' for parameter $name in schema definition";
 
+    $value //= $p->{default};
+
     if (defined $value or Swagger2::SchemaValidator::_is_true($p->{required})) {
       my $type = $p->{type} || 'object';
       $value += 0 if $type =~ /^(?:integer|number)/ and $value =~ /^\d/;
