@@ -6,7 +6,7 @@ Swagger2 - Swagger RESTful API Documentation
 
 =head1 VERSION
 
-0.33
+0.34
 
 =head1 DESCRIPTION
 
@@ -59,12 +59,12 @@ use File::Spec;
 use constant CACHE_DIR => $ENV{SWAGGER2_CACHE_DIR} || '';
 use constant DEBUG     => $ENV{SWAGGER2_DEBUG}     || 0;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 # Should be considered internal
 our @SPEC_FILE = (File::Spec->splitdir(File::Basename::dirname(__FILE__)), 'Swagger2', 'schema.json');
 
-my @YAML_MODULES = qw( YAML::Tiny YAML YAML::Syck YAML::XS );
+my @YAML_MODULES = qw( YAML::XS YAML::Syck YAML::Tiny YAML );
 my $YAML_MODULE = $ENV{SWAGGER2_YAML_MODULE} || (grep { eval "require $_;1" } @YAML_MODULES)[0] || 'Swagger2::FALLBACK';
 
 sub Swagger2::FALLBACK::Dump { die "Need to install a YAML module: @YAML_MODULES"; }
